@@ -469,7 +469,7 @@ class PermissionBoundary(
     def __init__(
         self,
         *,
-        customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_ceddda9d.IResolvable]] = None,
+        customer_managed_policy_reference: typing.Optional[typing.Union[_aws_cdk_ceddda9d.IResolvable, typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
         managed_policy_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -489,7 +489,7 @@ class PermissionBoundary(
     @builtins.property
     def customer_managed_policy_reference(
         self,
-    ) -> typing.Optional[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, _aws_cdk_ceddda9d.IResolvable]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_ceddda9d.IResolvable, _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty]]:
         '''Specifies the name and path of a customer managed policy.
 
         You must have an IAM policy that matches the name and path in each AWS account where you want to deploy your permission set.
@@ -497,7 +497,7 @@ class PermissionBoundary(
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-permissionsboundary.html#cfn-sso-permissionset-permissionsboundary-customermanagedpolicyreference
         '''
         result = self._values.get("customer_managed_policy_reference")
-        return typing.cast(typing.Optional[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, _aws_cdk_ceddda9d.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_ceddda9d.IResolvable, _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty]], result)
 
     @builtins.property
     def managed_policy_arn(self) -> typing.Optional[builtins.str]:
@@ -1051,7 +1051,7 @@ def _typecheckingstub__63d08775b809b0e566cdb84b9c89847ac6e6605d16d5345595d249a8f
 
 def _typecheckingstub__4b19ce1fb3e89b904939ce873e787c40e49146fc1e9defc30a9c9e3df0a22c16(
     *,
-    customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_ceddda9d.IResolvable]] = None,
+    customer_managed_policy_reference: typing.Optional[typing.Union[_aws_cdk_ceddda9d.IResolvable, typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
     managed_policy_arn: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
